@@ -2,7 +2,7 @@
 # SPDX-License-Identifier: Apache-2.0
 
 
-import requests, typing, dataclasses, uuid
+import requests, typing, dataclasses, uuid, math
 
 from cryptography.hazmat.primitives.asymmetric.ed25519 import Ed25519PublicKey
 from cryptography.exceptions import InvalidSignature
@@ -151,7 +151,7 @@ class Client:
         try:
             _, public_key = self.get_base_url_and_compliance_key(request_sender_address)
         except ValueError as e:
-            raise protocol_error(ErrorCode.invalid_x_request_sender_address, str(e)) from e
+            raise protocol_error(ErrorCode.invalid_http_header, str(e)) from e
 
         request = _deserialize_jws(request_bytes, CommandRequestObject, public_key, command_error)
         if request.command_type == CommandType.PaymentCommand:
@@ -186,11 +186,11 @@ class Client:
         limit = self.jsonrpc_client.get_metadata().dual_attestation_limit
         for info in currencies:
             if info.code == action.currency:
-                approx_xdx_microdiem_value = info.to_xdx_exchange_rate * action.amount
-                if approx_xdx_microdiem_value < limit:
+                if _is_under_the_threshold(limit, info.to_xdx_exchange_rate, action.amount):
                     raise command_error(
                         ErrorCode.no_kyc_needed,
-                        f"payment amount is under travel rule threshold {limit}",
+                        "payment amount is %s (rate: %s) under travel rule threshold %s"
+                        % (action.amount, info.to_xdx_exchange_rate, limit),
                         "command.payment.action.amount",
                     )
                 return
@@ -218,7 +218,7 @@ class Client:
     def validate_request_sender_address(self, request_sender_address: str, addresses: typing.List[str]) -> None:
         if request_sender_address not in addresses:
             raise command_error(
-                ErrorCode.invalid_x_request_sender_address,
+                ErrorCode.invalid_http_header,
                 f"address {request_sender_address} is not one of {addresses}",
             )
 
@@ -228,7 +228,7 @@ class Client:
         if self.is_my_account_id(obj.receiver.address):
             return PaymentCommand(cid=cid, my_actor_address=obj.receiver.address, payment=obj, inbound=True)
 
-        raise command_error(ErrorCode.unknown_actor_address, "unknown actor addresses: {obj}")
+        raise command_error(ErrorCode.unknown_address, "unknown actor addresses: {obj}")
 
     def is_my_account_id(self, account_id: str) -> bool:
         account_address, _ = identifier.decode_account(account_id, self.hrp)
@@ -263,3 +263,11 @@ def _deserialize_jws(
         raise error_fn(ErrorCode.invalid_jws_signature, f"invalid jws signature: {e}", None) from e
     except ValueError as e:
         raise error_fn(ErrorCode.invalid_jws, f"deserialize JWS bytes failed: {e}", None) from e
+
+
+def _is_under_the_threshold(limit: int, rate: float, amount: int) -> bool:
+    # use ceil of the xdx exchanged amount to ensure a valid amount
+    # is not considered as under the threshold because of float number
+    # transport or calculation difference comparing with Move module
+    # implementation.
+    return math.ceil(rate * amount) < limit
